# h is the height of seed release,
# u is the mean horizontal windspeed during seed flight (m / s),
# f is the velocity of a Heracleum sosnowskyi seed falling in still air (m / s) 
# ----------------------------------------------------------------------------


# wind.speed.all.days is the vector with day by day wind speed at Syktyvkar airport meteostation in september of 2005, 2006, 2007, 2008, 2009, 2010, 2011 years (210 values from 1-st to 30-th of september 2005 in first 30 values, from 1-st to 30-th of september 2006 in next 30 values etc).

# release.height - the vector with heights (in cm) of Heracleum sosnowskyi generative plants (48 values)

# speed.median - the vector containing median velocity Heracleum sosnowskyi seed falling. Every median was calculatetd for 5 measurments for every of 15 seeds used. The measurments of time falling were made in the still air indoors from height of 3 m.

ws<-read.table("wind_speed_in_September_2005-2011.csv", sep=";", head=T)
wind.speed.all.days<-na.omit(ws[,2])

seeds<-read.table("time_of_seed_falling_size_mass_of_seed_heracleum_2013.csv", head=T, sep=";", dec=",")
t.median<-tapply(seeds[,3],seeds[,1], median)
speed.median<-3/t.median

plant.height<-read.table("plant_heihgt.csv", head=T, sep=";", dec=",")
release.height<-plant.height$h

hseedm<-function (h,u,f){
# Initialization the first value of variables and first values of  vector "distance" - the distance of Heracleum sosnowskyi seeds can reach by fly from mother plant.

h=sample(release.height/100, 1)
u=sample(wind.speed.all.days, 1)
f=sample(speed.median, 1)

d=h/f*u
distance<-d
# 
for (i in 1: 20000){
h=sample(release.height/100, 1)
u=sample(wind.speed.all.days, 1)
f=sample(speed.median, 1)
w=0
d=h/f*u #
# append(1:5, 0:1, after = 3)
distance<-append(distance, d, after=i)
}

x<-distance

#Compute an empirical cumulative distribution function
a<-ecdf(x)

#Now use this "ecdf function" to generate the cumulative probabilities of any vector you feed it, including your original, sorted data:
my.ecdf <- a(sort(x))

#Find indexes of vector my.ecdf with interesting threshold values 
i_90<-which(my.ecdf >= 0.90)[1]
i_95<-which(my.ecdf >= 0.95)[1]
i_99<-which(my.ecdf >= 0.99)[1]

#Find vaulues in my.ecdf and in x vectors with indexes i_90, i_95, i_99 
h_90<-my.ecdf[i_90]
v_90<-sort(x)[i_90]

h_95<-my.ecdf[i_95]
v_95<-sort(x)[i_95]

h_99<-my.ecdf[i_99]
v_99<-sort(x)[i_99]

#Plot with interesting thresholds. Lines of threshold are added by abline()

pdf(file="Distance probabilyty cumulative distribution.pdf")

plot(a,ylab="Probabilyty cumulative distribution", xlab="Distance, m", verticals = F, do.points = F)

lines(c(v_90,v_90), c(0,h_90), type="l")# distance on x-axis which is the radius of 90 % seed dispersal
lines(c(0,v_90), c(h_90,h_90), type="l")

lines(c(v_95,v_95), c(0,h_95), type="l")# distance on x-axis which is the radius of 95 % seed dispersal
lines(c(0,v_95), c(h_95,h_95), type="l")

lines(c(v_99,v_99), c(0,h_99), type="l")# distance on x-axis which is the radius of 99 % seed dispersal
lines(c(0,v_99), c(h_99,h_99), type="l")

# Print text on y-axis
text(0, h_90, labels=sprintf("%.2f", round(h_90,2)), pos=2, offset=0.1, cex=0.7)
text(0, h_95, labels=sprintf("%.2f", round(h_95,2)), pos=2, offset=0.1, cex=0.7)
text(0, h_99, labels=sprintf("%.2f", round(h_99,2)), pos=2, offset=0.1, cex=0.7)

# Print text on x-axis
text(v_90, 0, labels=sprintf("%.0f", round(v_90,0)), pos=1, offset=0.1, cex=0.7)
text(v_95, 0, labels=sprintf("%.0f", round(v_95,0)), pos=1, offset=0.1, cex=0.7)
text(v_99, 0, labels=sprintf("%.0f", round(v_99,0)), pos=1, offset=0.1, cex=0.7)

dev.off()

return(distance)

}
